Welcome to Sorcha's Add-ons documentation!
======================================================

``Sorcha Add-ons`` is a collection of plugins that can be used to
model changes to the apparent magnitude (modeling effects of cometary activity or rotational light curve effects) for  objects simulated in the ``Sorcha``  Solar System simulator.

``Sorcha`` (pronounced "surk-ha") is an open-source Solar System survey simulator written in Python. ``Sorcha`` (pronounced "sur-kha"; derived from the Old Irish word for 'light' or 'brightness') is an open-source Solar System survey simulator written in Python.  ``Sorcha`` estimates the brightness of simulated Solar System small bodies and determines which ones the survey could detect in each of the survey's observations  based on user set criteria. ``Sorcha`` has been designed
with the `Vera C. Rubin Observatory Legacy Survey of Space and Time (LSST) <https://rubinobservatory.org>`_
in mind.  You can learn more about ``Sorcha`` `here <https://sorcha.readthedocs.io>`_. 


.. note::
   Contributions are very welcome. If you have a prescription for cometary activity or light curve effects for the ``Sorcha`` solar system survey simulator, we encourage you to  add your code to ``Sorcha add-ons``.  Further details can be found on our :ref:`contributing` page.

.. seealso::
   For a more detailed description of ``Sorcha``/``Sorcha add-ons`` and` and how it works, please see  `Merritt et al. (submitted) <https://www.dropbox.com/scl/fi/secetw7n0a936iynzxmau/sorcha_paper_2025_Jan_submission_version.pdf?rlkey=pbhchiattrw5bna8sfo6ljvto&dl=0>`_  and `Holman et al. (submitted) <https://www.dropbox.com/scl/fi/lz1lmua2s0yf9t9a2gpmm/sorcha_ephemeris_generation_paper.pdf?rlkey=blm9u4zbk0ci1i4lc5yqz8dbs&dl=0>`_.

.. warning::
   ``Sorcha`` is  currently under review. The code in the repository has been validated.
   We will release ``Sorcha`` and ``Sorcha add-ons``  v1.0 on PyPI and conda-forge when accepted. We ask
   that if you're external to the Sorcha team that you please wait to use ``Sorcha``/``Sorcha add-ons`` in your science papers until v1.0 of each are released.



.. toctree::
   :hidden:

   Home page <self>
   Installation <installation> 
   Usage <usage>
   Community Modules <community_modules>
   Notebooks <notebooks>
   Contributing <contributing>
   API Reference <autoapi/index>
